==> voreen-src-4.2-win.zip: voreen-src-4.2-win/modules/stereoscopy/qt/processor/stereoscopyprocessorwidgetfactory.cpp <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2013 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#include "stereoscopyprocessorwidgetfactory.h"

#include "../../processors/stereocanvasrenderer.h"
#include "modules/core/qt/processor/canvasrendererwidget.h"

#include "voreen/qt/voreenapplicationqt.h"

#include <QMainWindow>

namespace voreen {

ProcessorWidget* StereoscopyProcessorWidgetFactory::createWidget(Processor* processor) const {
    if (!VoreenApplicationQt::qtApp()) {
        LERRORC("voreen.stereoscopy.qt.processor.StereoscopyProcessorWidgetFactory", "VoreenApplicationQt not instantiated");
        return 0;
    }
    if (!processor)
        return 0;
    QWidget* parent = VoreenApplicationQt::qtApp()->getMainWindow();

    if (typeid(*processor) == typeid(StereoCanvasRenderer))
        return new CanvasRendererWidget(parent, static_cast<StereoCanvasRenderer*>(processor));
    else
        return 0;
}
} // namespace voreen

==> voreen-src-4.4-win.zip: voreen-src-4.4-win/modules/stereoscopy/qt/processor/stereoscopyprocessorwidgetfactory.cpp <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2013 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#include "stereoscopyprocessorwidgetfactory.h"

#include "../../processors/stereocanvasrenderer.h"
#include "stereocanvasrendererwidget.h"

#include "voreen/qt/voreenapplicationqt.h"

#include <QMainWindow>

namespace voreen {

ProcessorWidget* StereoscopyProcessorWidgetFactory::createWidget(Processor* processor) const {
    if (!VoreenApplicationQt::qtApp()) {
        LERRORC("voreen.stereoscopy.qt.processor.StereoscopyProcessorWidgetFactory", "VoreenApplicationQt not instantiated");
        return 0;
    }
    if (!processor)
        return 0;
    QWidget* parent = VoreenApplicationQt::qtApp()->getMainWindow();

    if (typeid(*processor) == typeid(StereoCanvasRenderer))
        return new StereoCanvasRendererWidget(parent, static_cast<StereoCanvasRenderer*>(processor));
    else
        return 0;
}
} // namespace voreen
